/*-------------------------------------------------------------------------+
| Copyright 2018 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.generator.extension.library;

import static org.fortiss.af3.generator.common.utils.SourceModelElementFactory.createByteContentUnitForPluginFileInRCP;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.af3.generator.common.model.source.ByteContentUnit;
import org.fortiss.af3.platform.language.executable.ExecutableBase;
import org.fortiss.af3.platform.raspberry.AF3PlatformRaspberryActivator;
import org.fortiss.af3.platform.raspberry.generator.framework.IRasPiHeaderGeneratorExtension;
import org.fortiss.af3.platform.raspberry.generator.framework.IRasPiLibraryBasedGeneratorExtension;

/**
 * Base class for executables using the AF3 Pi HAL library.
 * 
 * @author hoelzl
 */
public abstract class BrickLibraryGeneratorExtensionBase<T extends EObject> extends ExecutableBase<T>
		implements IRasPiLibraryBasedGeneratorExtension, IRasPiHeaderGeneratorExtension {
	/** Constructor. */
	public BrickLibraryGeneratorExtensionBase(T modelElement) {
		super(modelElement);
	}

	/** {@inheritDoc} */
	@Override
	public final String getLibraryFileName() {
		return "libbrick.a";
	}

	/** {@inheritDoc} */
	@Override
	public final ByteContentUnit getLibraryFileContent() {
		return createByteContentUnitForPluginFileInRCP(AF3PlatformRaspberryActivator.PLUGIN_ID,
				"code-gen-hal/lib", "libbrick.a", false);
	}

	/** {@inheritDoc} */
	@Override
	public final ByteContentUnit getHeaderFileContent() {
		return createByteContentUnitForPluginFileInRCP(AF3PlatformRaspberryActivator.PLUGIN_ID,
				"code-gen-hal/inc/brick", getHeaderFileName(), false);
	}
}
